@@ -37,11 +37,15 @@ log = jip.logger.getLogger('job.cli')
 # Color definitions
 ##############################################################################
 NORMAL = ''
-BLUE = '\033[94m'
-GREEN = '\033[92m'
-YELLOW = '\033[93m'
-RED = '\033[91m'
-ENDC = '\033[0m'
+BLACK   = '\033[90m'
+RED     = '\033[91m'
+GREEN   = '\033[92m'
+YELLOW  = '\033[93m'
+BLUE    = '\033[94m'
+MAGENTA = '\033[95m'
+CYAN    = '\033[96m'
+WHITE   = '\033[97m'
+ENDC    = '\033[0m'
 
 #: Maps job states to colors
 STATE_COLORS = {
