@@ -61,6 +61,7 @@ import jip.tools
 import jip.cli
 import jip.cluster
 import jip.configuration
+import jip.templates
 
 from jip.logger import getLogger, log_level
 from jip.vendor.docopt import docopt
@@ -87,6 +88,11 @@ def main():
         sys.stderr.write(str(va))
         sys.stderr.write("\n")
         sys.exit(1)
+    except jip.templates.RenderError as va:
+        log.debug("render error: %s", str(va), exc_info=True)
+        sys.stderr.write(str(va))
+        sys.stderr.write("\n")
+        sys.exit(1)
     except jip.tools.ToolNotFoundException as notFound:
         log.debug("Tool not found: %s", str(notFound), exc_info=True)
         print >>sys.stderr, jip.cli.colorize(str(notFound), jip.cli.RED)
