@@ -344,12 +344,23 @@ def _setup_signal_handler(job, save=False):
     :type job: :class:`jip.db.Job`
     :param session: optional database session
     """
+
     def handle_signal(signum, frame):
         log.warn("Signal %s received, going to fail state", signum)
+
+        # Some signal arrived and maybe the job object is detached,
+        # we need to re-create the session and re-attach the object
+        from sqlalchemy import inspect
+        insp = inspect(job)
+        if insp.detached:
+            session = jip.db.create_session()
+            session.add(job)
+
         set_state(job, jip.db.STATE_FAILED, check_state=save)
         if save:
             db.update_job_states([job] + job.pipe_to)
         sys.exit(1)
+        
     log.debug("Setting up signal handler for %s", job)
     signal(SIGTERM, handle_signal)
     signal(SIGINT, handle_signal)
@@ -582,13 +593,13 @@ def submit_job(job, clean=False, force=False, save=True,
     ``jip.cluster.ClusterImplementationError`` in case no compute cluster is
     configured.
 
-    :param job: the job to be deleted
-    :param clean: if True, the job log files will be deleted
+    :param job: the job to be submitted
+    :param clean: if True, the job log files will be submitted
     :param force: force job submission
-    :param save: if True, jobs will be saved to the database
+    :param save: if True, job will be saved to the database
     :param cluster: the compute cluster instance. If ``None``, the default
                     cluster will be loaded from the jip configuration
-    :returns: True if the jobs was submitted
+    :returns: True if the job was submitted
     :raises jip.cluster.ClusterImplementationError: if no cluster could be
                                                     loaded
     """
@@ -657,7 +668,7 @@ def submit_job(job, clean=False, force=False, save=True,
     return True
 
 
-def run_job(job, save=False, profiler=False, submit_embedded=False):
+def run_job(job, save=False, profiler=False, submit_embedded=False, closeDB=False):
     """Execute the given job. This method returns immediately in case the
     job has a pipe source. Otherwise the job and all its dispatch jobs are
     executed.
@@ -676,10 +687,10 @@ def run_job(job, save=False, profiler=False, submit_embedded=False):
     """
     if len(job.pipe_from) > 0:
         return
-    # setup signal handeling
+    # setup signal handling
     _setup_signal_handler(job, save=save)
 
-    # createa the dispatcher graph
+    # create the dispatcher graph
     dispatcher_nodes = jip.executils.create_dispatcher_graph(job)
     log.info("%s | Dispatch graph: %s", job, dispatcher_nodes)
     # load job environment
@@ -697,6 +708,7 @@ def run_job(job, save=False, profiler=False, submit_embedded=False):
         if not os.path.exists(child.working_directory):
             os.makedirs(child.working_directory)
 
+    # Execute the commands
     for dispatcher_node in dispatcher_nodes:
         dispatcher_node.run(profiler=profiler)
 
@@ -706,11 +718,23 @@ def run_job(job, save=False, profiler=False, submit_embedded=False):
         db.update_job_states(all_jobs)
 
     success = True
-    # we collect the state of all job in the dispatcher first
-    # a single failure will case ALL nodes/jobs in that dispatcher
+
+    # Close the DB connection for the execution of the commands,
+    # the job object gets the detached state
+    session=jip.db.create_session()
+    jip.db.commit_session(session)
+    session.close()
+
+    # we collect the state of all jobs in the dispatcher first
+    # a single failure will cause ALL nodes/jobs in that dispatcher
     # to be marked as failed
     for dispatcher_node in reversed(dispatcher_nodes):
         success &= dispatcher_node.wait()
+
+    # The commands finished their execution, re-attach the job object
+    session = jip.db.create_session()
+    session.add(job)
+
     # get the new state and update all jobs
     new_state = db.STATE_DONE if success else db.STATE_FAILED
     for dispatcher_node in reversed(dispatcher_nodes):
@@ -867,14 +891,14 @@ def from_node(node, env=None, keep=False):
     """Create and return a :class:`jip.db.Job` instance from a
     :class:`~jip.pipelines.Node`.
 
-    A dictinary with the jobs environment can be passed here to avoid creating
+    A dictionary with the job environment can be passed here to avoid creating
     the environment for each job.
 
     :param node: the node
     :type node: :class:`jip.pipelines.Node`
     :param env: the environment stored for the job. If None, this will be
                 generated.
-    :param keep: keep the jobs output on failuer
+    :param keep: keep the job output on failure
     :type keep: bool
     :returns: the created job
     :rtype: :class:`jip.db.Job`
@@ -883,7 +907,7 @@ def from_node(node, env=None, keep=False):
     tool = node._tool
     job.state = jip.db.STATE_HOLD
     #job.name = tool.name
-    log.debug("Jobs | Creating node %s", job.name)
+    log.debug("Jobs | Creating job for node %s", node.name)
 
     # get current user
     job.user = getpass.getuser()
@@ -902,6 +926,7 @@ def from_node(node, env=None, keep=False):
         node._job.apply(job)
     job.name = node.name
     job.pipeline = node._pipeline
+    job.pipeline_name = node._pipeline_name
 
     # update job defaults after the profile is applied
     if not job.threads:
@@ -1009,7 +1034,7 @@ def create_jobs(source, args=None, excludes=None, skip=None, keep=False,
 
     After all jobs are created, they are validated and a `ValidationError` is
     raised if a job is not valid.
-    Please not that the output files of the jobs are not checked automatically.
+    Please note that the output files of the jobs are not checked automatically.
     You might want to call :py:func:`~jip.jobs.check_output_files` after
     you created all your jobs.
 
@@ -1019,7 +1044,7 @@ def create_jobs(source, args=None, excludes=None, skip=None, keep=False,
                  to tool instances
     :param excludes: excludes nodes by name. This removed the node and the
                      full subgraph after the node
-    :param skip: skip the node. This does not touch teh subgraph but tries
+    :param skip: skip the node. This does not touch the subgraph but tries
                  to connect the nodes input with the nodes output before the
                  node is removed
     :param keep: keep the jobs output on failure
@@ -1060,7 +1085,7 @@ def create_jobs(source, args=None, excludes=None, skip=None, keep=False,
         log.info("Jobs | Pipeline has %d nodes after skipping", len(pipeline))
 
     # create all jobs. We keep the list for the order and
-    # a dict to store the mapping from the node to teh job
+    # a dict to store the mapping from the node to the job
     log.debug("Jobs | Creating job environment for %d nodes", len(pipeline))
     nodes2jobs = {}
     jobs = []
