@@ -6,7 +6,7 @@ job, such as the number of threads reserved for the job or the time limit.
 Profiles can be named and stored in the user configuration.
 
 In addition, hierarchical updates of profiles can be applied. For example, a
-default profile can be loaded from the configuration. This profile can than be
+default profile can be loaded from the configuration. This profile can then be
 refined by a pipeline script or command line options.
 
 This enable you to start with a *hard-coded* profile in your tool
@@ -187,7 +187,7 @@ class Profile(object):
             if fnmatch.fnmatch(node.name, spec_name):
             #if re.match(spec_name, node.name):
                 if not node_profile:
-                    node_profile = spec
+                    node_profile = spec()
                 else:
                     node_profile.update(spec)
 
@@ -410,8 +410,10 @@ class Profile(object):
             job.priority = self.priority
         if self.time is not None and job.max_time is None:
             job.max_time = jip.utils.parse_time(self.time)
-        if self.mem is not None and job.max_memory is None:
-            job.max_memory = jip.utils.parse_mem(self.mem)
+        if self.mem is not None:
+            if job.max_memory is None:
+                job.max_memory = 0
+            job.max_memory += jip.utils.parse_mem(self.mem)
         if self.log is not None and job.stderr is None:
             job.stderr = self._render(job, self.log)
         if self.out is not None and job.stdout is None:
@@ -549,7 +551,12 @@ class Profile(object):
         :param file_name: the name of the input file
         """
         with open(file_name) as of:
-            data = json.load(of)
+            try:
+                data = json.load(of)
+            except ValueError:
+                log.error("Malformed json file %s", file_name)
+                raise jip.ValidationError('jip.profiles', "Malformed json file %s" % (file_name))
+
             return cls.from_dict(data)
 
     @classmethod
@@ -567,8 +574,8 @@ class Profile(object):
 
 
 def get(name='default', tool=None):
-    """Load a profile by name. If tools is speciefied, the specs are
-    searched to the tool and if found, the spec is applied.
+    """Load a profile by name. If tool is specified, the specs are
+    searched to the tool and if found, the specs are applied.
     """
     # check the name for specs
     s = name.split(' ')
@@ -593,19 +600,28 @@ def get_specs(path=None):
 
     :param path: optional path to an additional spec file
     """
+    
+    def load_json(jf):
+        with open(jf) as of:
+            try:
+                data = json.load(of)
+            except ValueError:
+                log.error("Malformed json file %s", jf)
+                raise jip.ValidationError('jip.profiles', "Malformed json file %s" % (jf))
+        
+        return data
+    
     global specs
     cwd = os.path.join(os.getcwd(), "jip.specs")
     home = os.path.join(os.getenv("HOME", ""), ".jip/jip.specs")
     specs = {}
     if os.path.exists(home):
-        with open(home) as of:
-            specs = _update(specs, json.load(of))
+        specs = _update(specs, load_json(home))
     if os.path.exists(cwd):
-        with open(cwd) as of:
-            specs = _update(specs, json.load(of))
+        specs = _update(specs, load_json(cwd))
     if path and os.path.exists(path):
-        with open(path) as of:
-            specs = _update(specs, json.load(of))
+        specs = _update(specs, load_json(path))
+        
     return specs
 
 
